@@ -29,6 +29,7 @@
 #include "translucentbutton.h"
 #include "platform.h"
 #include "progressdialog.h"
+#include "sortedlibrary.h"
 
 #ifdef DORIAN_TEST_MODEL
 #   include "modeltest.h"
@@ -166,7 +167,8 @@ void MainWindow::initialize()
             if (!library->rowCount()) {
                 library->add(":/books/2BR02B.epub");
             }
-            library->setNowReading(library->index(0));
+            SortedLibrary sorted;
+            library->setNowReading(sorted.mapToSource(sorted.index(0, 0)));
         }
     }
 }
@@ -298,7 +300,6 @@ void MainWindow::showBookmarks()
     Book *book = Library::instance()->book(mCurrent);
     if (book) {
         BookmarksDialog *bookmarks = new BookmarksDialog(book, this);
-        bookmarks->setWindowModality(Qt::WindowModal);
         connect(bookmarks, SIGNAL(addBookmark(const QString &)),
                 this, SLOT(onAddBookmark(const QString &)));
         connect(bookmarks, SIGNAL(goToBookmark(int)),
@@ -390,7 +391,6 @@ void MainWindow::showChapters()
     Book *book = Library::instance()->book(mCurrent);
     if (book) {
         ChaptersDialog *chapters = new ChaptersDialog(book, this);
-        chapters->setWindowModality(Qt::WindowModal);
         connect(chapters, SIGNAL(goToChapter(int)),
                 this, SLOT(onGoToChapter(int)));
         chapters->show();
