@@ -7,7 +7,6 @@
 #include "listwindow.h"
 #include "search.h"
 
-class ListView;
 class QModelIndex;
 class ProgressDialog;
 
@@ -21,7 +20,6 @@ public:
                                  QWidget *parent = 0);
 
 protected slots:
-    void onDownload();
     void onItemActivated(const QModelIndex &index);
     void onBeginDownload(int size);
     void onEndDownload(int status, const Search::Result &result,
@@ -32,7 +30,6 @@ protected:
 
 private:
     const QList<Search::Result> results;
-    ListView *list;
     QStringList data;
     ProgressDialog *progress;
 };
